==> route53-1.60.0-sources.jar: software/amazon/awscdk/services/route53/PublicHostedZone.java <==
package software.amazon.awscdk.services.route53;

/**
 * Create a Route53 public hosted zone.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.271Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.PublicHostedZone")
public class PublicHostedZone extends software.amazon.awscdk.services.route53.HostedZone implements software.amazon.awscdk.services.route53.IPublicHostedZone {

    protected PublicHostedZone(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PublicHostedZone(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public PublicHostedZone(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.PublicHostedZoneProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import a Route 53 public hosted zone defined either outside the CDK, or in a different CDK stack.
     * <p>
     * @param scope the parent Construct for this Construct. This parameter is required.
     * @param id the logical name of this Construct. This parameter is required.
     * @param publicHostedZoneId the ID of the public hosted zone to import. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IPublicHostedZone fromPublicHostedZoneId(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String publicHostedZoneId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.PublicHostedZone.class, "fromPublicHostedZoneId", software.amazon.awscdk.services.route53.IPublicHostedZone.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(publicHostedZoneId, "publicHostedZoneId is required") });
    }

    /**
     * Adds a delegation from this zone to a designated zone.
     * <p>
     * @param delegate the zone being delegated to. This parameter is required.
     * @param opts options for creating the DNS record, if any.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDelegation(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IPublicHostedZone delegate, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.route53.ZoneDelegationOptions opts) {
        this.jsiiCall("addDelegation", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(delegate, "delegate is required"), opts });
    }

    /**
     * Adds a delegation from this zone to a designated zone.
     * <p>
     * @param delegate the zone being delegated to. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDelegation(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IPublicHostedZone delegate) {
        this.jsiiCall("addDelegation", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(delegate, "delegate is required") });
    }

    /**
     * Add another VPC to this private hosted zone.
     * <p>
     * @param _vpc This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void addVpc(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IVpc _vpc) {
        this.jsiiCall("addVpc", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(_vpc, "_vpc is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.route53.PublicHostedZone}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.route53.PublicHostedZone> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.route53.PublicHostedZoneProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.route53.PublicHostedZoneProps.Builder();
        }

        /**
         * The name of the domain.
         * <p>
         * For resource record types that include a domain
         * name, specify a fully qualified domain name.
         * <p>
         * @return {@code this}
         * @param zoneName The name of the domain. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder zoneName(final java.lang.String zoneName) {
            this.props.zoneName(zoneName);
            return this;
        }

        /**
         * Any comments that you want to include about the hosted zone.
         * <p>
         * Default: none
         * <p>
         * @return {@code this}
         * @param comment Any comments that you want to include about the hosted zone. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comment(final java.lang.String comment) {
            this.props.comment(comment);
            return this;
        }

        /**
         * The Amazon Resource Name (ARN) for the log group that you want Amazon Route 53 to send query logs to.
         * <p>
         * Default: disabled
         * <p>
         * @return {@code this}
         * @param queryLogsLogGroupArn The Amazon Resource Name (ARN) for the log group that you want Amazon Route 53 to send query logs to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryLogsLogGroupArn(final java.lang.String queryLogsLogGroupArn) {
            this.props.queryLogsLogGroupArn(queryLogsLogGroupArn);
            return this;
        }

        /**
         * Whether to create a CAA record to restrict certificate authorities allowed to issue certificates for this domain to Amazon only.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param caaAmazon Whether to create a CAA record to restrict certificate authorities allowed to issue certificates for this domain to Amazon only. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder caaAmazon(final java.lang.Boolean caaAmazon) {
            this.props.caaAmazon(caaAmazon);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.route53.PublicHostedZone}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.route53.PublicHostedZone build() {
            return new software.amazon.awscdk.services.route53.PublicHostedZone(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> route53-1.100.0-sources.jar: software/amazon/awscdk/services/route53/PublicHostedZone.java <==
package software.amazon.awscdk.services.route53;

/**
 * Create a Route53 public hosted zone.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:22.496Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.PublicHostedZone")
public class PublicHostedZone extends software.amazon.awscdk.services.route53.HostedZone implements software.amazon.awscdk.services.route53.IPublicHostedZone {

    protected PublicHostedZone(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PublicHostedZone(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public PublicHostedZone(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.PublicHostedZoneProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import a Route 53 public hosted zone defined either outside the CDK, or in a different CDK stack.
     * <p>
     * @param scope the parent Construct for this Construct. This parameter is required.
     * @param id the logical name of this Construct. This parameter is required.
     * @param publicHostedZoneId the ID of the public hosted zone to import. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IPublicHostedZone fromPublicHostedZoneId(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String publicHostedZoneId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.PublicHostedZone.class, "fromPublicHostedZoneId", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.IPublicHostedZone.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(publicHostedZoneId, "publicHostedZoneId is required") });
    }

    /**
     * Adds a delegation from this zone to a designated zone.
     * <p>
     * @param delegate the zone being delegated to. This parameter is required.
     * @param opts options for creating the DNS record, if any.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDelegation(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IPublicHostedZone delegate, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.route53.ZoneDelegationOptions opts) {
        software.amazon.jsii.Kernel.call(this, "addDelegation", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(delegate, "delegate is required"), opts });
    }

    /**
     * Adds a delegation from this zone to a designated zone.
     * <p>
     * @param delegate the zone being delegated to. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDelegation(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IPublicHostedZone delegate) {
        software.amazon.jsii.Kernel.call(this, "addDelegation", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(delegate, "delegate is required") });
    }

    /**
     * Add another VPC to this private hosted zone.
     * <p>
     * @param _vpc This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void addVpc(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IVpc _vpc) {
        software.amazon.jsii.Kernel.call(this, "addVpc", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(_vpc, "_vpc is required") });
    }

    /**
     * Role for cross account zone delegation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.iam.Role getCrossAccountZoneDelegationRole() {
        return software.amazon.jsii.Kernel.get(this, "crossAccountZoneDelegationRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.route53.PublicHostedZone}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.route53.PublicHostedZone> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.route53.PublicHostedZoneProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.route53.PublicHostedZoneProps.Builder();
        }

        /**
         * The name of the domain.
         * <p>
         * For resource record types that include a domain
         * name, specify a fully qualified domain name.
         * <p>
         * @return {@code this}
         * @param zoneName The name of the domain. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder zoneName(final java.lang.String zoneName) {
            this.props.zoneName(zoneName);
            return this;
        }

        /**
         * Any comments that you want to include about the hosted zone.
         * <p>
         * Default: none
         * <p>
         * @return {@code this}
         * @param comment Any comments that you want to include about the hosted zone. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comment(final java.lang.String comment) {
            this.props.comment(comment);
            return this;
        }

        /**
         * The Amazon Resource Name (ARN) for the log group that you want Amazon Route 53 to send query logs to.
         * <p>
         * Default: disabled
         * <p>
         * @return {@code this}
         * @param queryLogsLogGroupArn The Amazon Resource Name (ARN) for the log group that you want Amazon Route 53 to send query logs to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryLogsLogGroupArn(final java.lang.String queryLogsLogGroupArn) {
            this.props.queryLogsLogGroupArn(queryLogsLogGroupArn);
            return this;
        }

        /**
         * Whether to create a CAA record to restrict certificate authorities allowed to issue certificates for this domain to Amazon only.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param caaAmazon Whether to create a CAA record to restrict certificate authorities allowed to issue certificates for this domain to Amazon only. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder caaAmazon(final java.lang.Boolean caaAmazon) {
            this.props.caaAmazon(caaAmazon);
            return this;
        }

        /**
         * A principal which is trusted to assume a role for zone delegation.
         * <p>
         * Default: - No delegation configuration
         * <p>
         * @return {@code this}
         * @param crossAccountZoneDelegationPrincipal A principal which is trusted to assume a role for zone delegation. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder crossAccountZoneDelegationPrincipal(final software.amazon.awscdk.services.iam.IPrincipal crossAccountZoneDelegationPrincipal) {
            this.props.crossAccountZoneDelegationPrincipal(crossAccountZoneDelegationPrincipal);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.route53.PublicHostedZone}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.route53.PublicHostedZone build() {
            return new software.amazon.awscdk.services.route53.PublicHostedZone(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
